import ecoscope


def test_ecomap_base():
    ecoscope.mapping.EcoMap()


def test_add_local_geotiff():
    m = ecoscope.mapping.EcoMap()
    m.add_local_geotiff("tests/sample_data/raster/uint8.tif", cmap=None)
    m.add_local_geotiff("tests/sample_data/raster/uint8.tif", cmap="jet")



import sys
import os
sys.path.append('../ecoscope')
from ecoscope.mapping.map import EcoMap

m=EcoMap(draw_control=False)

relative_path=os.path.join('tests/test_output/png_map.png')
m.to_png(relative_path)